// Copyright (c) 2020, 2021 Famedly
//
// This software is released under the MIT License.
// https://opensource.org/licenses/MIT

import 'package:flutter/material.dart';

class ViewData {
  final String routeName;
  final bool displayTopBar;
  final bool expandRightView;
  final Widget Function(BuildContext) leftView;
  final Widget Function(BuildContext) mainView;
  final Widget Function(BuildContext) rightView;
  final Widget Function(BuildContext) emptyView;
  Widget Function(BuildContext) get focusView => rightView ?? mainView;

  /// Use [leftView] to display a left column next to the [mainView]. It will only
  /// be displayed if there is enough space. Use [rightView] too to create a three
  /// column layout. If the screen is in columnMode but not wide enough to display
  /// more than 2 columns, it will display the [rightView] in the center and the
  /// [leftView] on the left side.
  ///
  /// If you want the [mainView] to be on the left side and an empty view expanding
  /// in the center, use [emptyView].
  ///
  /// If you want the [rightView] to be expanded then set [expandRightView] to
  /// [true].
  ViewData({
    this.routeName,
    this.displayTopBar = true,
    this.expandRightView = false,
    this.leftView,
    @required this.mainView,
    this.rightView,
    this.emptyView,
  });
}
